@@ -1,6 +1,8 @@
-from datetime import *
+# The current module will entirely substitute datetime, hence:
+from datetime import *  # noqa
 from datetime import datetime as original_datetime
 
+
 class ReplacementSubclassMeta(type):
     """A metaclass for classes that subclass a given one to replace it.
 
@@ -60,4 +62,3 @@ class datetime(original_datetime):
         of 'now'.
         """
         cls.set_now(None)
-
